==> virtualbox-0.1-sources.jar: hudson/plugins/virtualbox/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.virtualbox;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * VirtualBox
     * 
     */
    public static String VirtualBoxHost_displayName() {
        return holder.format("VirtualBoxHost.displayName");
    }

    /**
     * VirtualBox
     * 
     */
    public static Localizable _VirtualBoxHost_displayName() {
        return new Localizable(holder, "VirtualBoxHost.displayName");
    }

    /**
     * VirtualBox Slave
     * 
     */
    public static String VirtualBoxSlave_displayName() {
        return holder.format("VirtualBoxSlave.displayName");
    }

    /**
     * VirtualBox Slave
     * 
     */
    public static Localizable _VirtualBoxSlave_displayName() {
        return new Localizable(holder, "VirtualBoxSlave.displayName");
    }

    /**
     * Unable to start {0}...
     * 
     */
    public static String VirtualBoxLauncher_startFailed(Object arg1) {
        return holder.format("VirtualBoxLauncher.startFailed", arg1);
    }

    /**
     * Unable to start {0}...
     * 
     */
    public static Localizable _VirtualBoxLauncher_startFailed(Object arg1) {
        return new Localizable(holder, "VirtualBoxLauncher.startFailed", arg1);
    }

    /**
     * Launch a VirtualBox machine
     * 
     */
    public static String VirtualBoxLauncher_displayName() {
        return holder.format("VirtualBoxLauncher.displayName");
    }

    /**
     * Launch a VirtualBox machine
     * 
     */
    public static Localizable _VirtualBoxLauncher_displayName() {
        return new Localizable(holder, "VirtualBoxLauncher.displayName");
    }

    /**
     * VirtualBox
     * 
     */
    public static String VirtualBoxBuildWrapper_displayName() {
        return holder.format("VirtualBoxBuildWrapper.displayName");
    }

    /**
     * VirtualBox
     * 
     */
    public static Localizable _VirtualBoxBuildWrapper_displayName() {
        return new Localizable(holder, "VirtualBoxBuildWrapper.displayName");
    }

    /**
     * Powering up {0}...
     * 
     */
    public static String VirtualBoxLauncher_startVM(Object arg1) {
        return holder.format("VirtualBoxLauncher.startVM", arg1);
    }

    /**
     * Powering up {0}...
     * 
     */
    public static Localizable _VirtualBoxLauncher_startVM(Object arg1) {
        return new Localizable(holder, "VirtualBoxLauncher.startVM", arg1);
    }

    /**
     * Powering down {0}...
     * 
     */
    public static String VirtualBoxLauncher_stopVM(Object arg1) {
        return holder.format("VirtualBoxLauncher.stopVM", arg1);
    }

    /**
     * Powering down {0}...
     * 
     */
    public static Localizable _VirtualBoxLauncher_stopVM(Object arg1) {
        return new Localizable(holder, "VirtualBoxLauncher.stopVM", arg1);
    }

}

==> virtualbox-0.2-sources.jar: hudson/plugins/virtualbox/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.virtualbox;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * VirtualBox
     * 
     */
    public static String VirtualBoxHost_displayName() {
        return holder.format("VirtualBoxHost.displayName");
    }

    /**
     * VirtualBox
     * 
     */
    public static Localizable _VirtualBoxHost_displayName() {
        return new Localizable(holder, "VirtualBoxHost.displayName");
    }

    /**
     * VirtualBox Slave
     * 
     */
    public static String VirtualBoxSlave_displayName() {
        return holder.format("VirtualBoxSlave.displayName");
    }

    /**
     * VirtualBox Slave
     * 
     */
    public static Localizable _VirtualBoxSlave_displayName() {
        return new Localizable(holder, "VirtualBoxSlave.displayName");
    }

    /**
     * Success
     * 
     */
    public static String VirtualBoxHost_success() {
        return holder.format("VirtualBoxHost.success");
    }

    /**
     * Success
     * 
     */
    public static Localizable _VirtualBoxHost_success() {
        return new Localizable(holder, "VirtualBoxHost.success");
    }

    /**
     * Unable to start {0}...
     * 
     */
    public static String VirtualBoxLauncher_startFailed(Object arg1) {
        return holder.format("VirtualBoxLauncher.startFailed", arg1);
    }

    /**
     * Unable to start {0}...
     * 
     */
    public static Localizable _VirtualBoxLauncher_startFailed(Object arg1) {
        return new Localizable(holder, "VirtualBoxLauncher.startFailed", arg1);
    }

    /**
     * Launch a VirtualBox machine
     * 
     */
    public static String VirtualBoxLauncher_displayName() {
        return holder.format("VirtualBoxLauncher.displayName");
    }

    /**
     * Launch a VirtualBox machine
     * 
     */
    public static Localizable _VirtualBoxLauncher_displayName() {
        return new Localizable(holder, "VirtualBoxLauncher.displayName");
    }

    /**
     * VirtualBox
     * 
     */
    public static String VirtualBoxBuildWrapper_displayName() {
        return holder.format("VirtualBoxBuildWrapper.displayName");
    }

    /**
     * VirtualBox
     * 
     */
    public static Localizable _VirtualBoxBuildWrapper_displayName() {
        return new Localizable(holder, "VirtualBoxBuildWrapper.displayName");
    }

    /**
     * Powering up {0}...
     * 
     */
    public static String VirtualBoxLauncher_startVM(Object arg1) {
        return holder.format("VirtualBoxLauncher.startVM", arg1);
    }

    /**
     * Powering up {0}...
     * 
     */
    public static Localizable _VirtualBoxLauncher_startVM(Object arg1) {
        return new Localizable(holder, "VirtualBoxLauncher.startVM", arg1);
    }

    /**
     * Powering down {0}...
     * 
     */
    public static String VirtualBoxLauncher_stopVM(Object arg1) {
        return holder.format("VirtualBoxLauncher.stopVM", arg1);
    }

    /**
     * Powering down {0}...
     * 
     */
    public static Localizable _VirtualBoxLauncher_stopVM(Object arg1) {
        return new Localizable(holder, "VirtualBoxLauncher.stopVM", arg1);
    }

}
